Struct open_feature::FlagMetadata
source · pub struct FlagMetadata {
pub values: HashMap<String, FlagMetadataValue>,
}Expand description
A structure which supports definition of arbitrary properties, with keys of type string, and values of type boolean, string, or number.
This structure is populated by a provider for use by an Application Author (via the Evaluation API) or an Application Integrator (via hooks).
Fields
values: HashMap<String, FlagMetadataValue>The fields of the metadata.
Implementations
sourceimpl FlagMetadata
impl FlagMetadata
sourcepub fn with_value(
self,
key: impl Into<String>,
value: impl Into<FlagMetadataValue>
) -> Self
pub fn with_value( self, key: impl Into<String>, value: impl Into<FlagMetadataValue> ) -> Self
Append givne key and value to the fields of metadata.